@@ -294,7 +294,7 @@ class AddEditScenarioFrame(BaseFrame):
         for text, col in ((u'Library',    frame.LIB_ENTRY_COLUMN),
                           (u'Modifier',   frame.MOD_ENTRY_COLUMN),
                           (u'Filter',     frame.FIL_ENTRY_COLUMN),
-                          (u'Override',   frame.OVR_ENTRY_COLUMN),
+                          (u'Hint',       frame.OVR_ENTRY_COLUMN),  # TODO: Strip out use of override - replace with 'Hint'
                           (u'Parameters', frame.PAR_ENTRY_COLUMN),
                           (u'Active',     frame.ACT_ENTRY_COLUMN),):
 
