@@ -16,6 +16,7 @@ class ServerConfigFrame(BaseLabelFrame):
     def __init__(self,
                  title=u'WebServer Config:',
                  intercept_server=None,
+                 redirect_address_list=None,
                  *args,
                  **kwargs):
 
@@ -24,6 +25,7 @@ class ServerConfigFrame(BaseLabelFrame):
                                                 **kwargs)
 
         self.http = HTTPServerConfigFrame(intercept_server=intercept_server,
+                                          redirect_address_list=redirect_address_list,
                                           column=Position.START,
                                           row=Position.START,
                                           sticky=EW)
