@@ -6,7 +6,8 @@ Modifies or adds to the received HTTP headers.
 Use "Content-Length: ?" to have the correct value added at
 runtime
 ------------------------------------------------------------
-Filter     : string to match in the request url
+Filter     : A regular expression to match in the
+             request url. Use * or .* to match all.
 Override   : N/A
 Parameters : Comma separated Key/Value pairs.
 ============================================================
@@ -24,7 +25,8 @@ def modify(request,
 
     modified_headers = {}
 
-    if modifier.passes_filter(request):
+    if modifier.passes_filter(value=request,
+                              wildcards='*'):
         # Set up parameters
         parse_dictionary_parameters(modifier)
 
