@@ -19,9 +19,7 @@ def modify(uri,
            modifier):
 
     string_to_match = modifier.filter
-    replacement_value = (modifier.override
-                         if modifier.override
-                         else modifier.params)
+    replacement_value = modifier.params
 
     uri = uri.replace(string_to_match,
                       replacement_value)
