@@ -2,6 +2,6 @@
 
 from .webserver import WebServer
 
-from .request import RequestHandler
+from .request_handler import RequestHandler
 
 from .server import InterceptServer
